@@ -214,7 +214,7 @@ void Autostart::load()
 
                 int indexPath = m_paths.indexOf((item->fileName().adjusted(QUrl::RemoveFilename).toString() ) );
                 if ( indexPath > 2 )
-                    indexPath = 0; //.kde/share/autostart and .config/autostart load destkop at startup
+                    indexPath = 0; //.kde/share/autostart and .config/autostart load desktop at startup
                 addItem(item, config.readName(), m_pathName.value(indexPath),  grp.readEntry("Exec"), disabled );
             }
         }
@@ -451,10 +451,10 @@ void Autostart::slotChangeStartup( ScriptStartItem* item, int index )
 
 void Autostart::slotSelectionChanged()
 {
-    const bool hasItems = ( dynamic_cast<AutoStartItem*>( widget->listCMD->currentItem() )!=0 ) ;
+    const bool hasItems = ( dynamic_cast<AutoStartItem*>( widget->listCMD->currentItem() )!=nullptr ) ;
     widget->btnRemove->setEnabled(hasItems);
 
-    const bool isDesktopItem = (dynamic_cast<DesktopStartItem*>(widget->listCMD->currentItem() ) != 0) ;
+    const bool isDesktopItem = (dynamic_cast<DesktopStartItem*>(widget->listCMD->currentItem() ) != nullptr) ;
     widget->btnProperties->setEnabled(isDesktopItem);
     widget->btnAdvanced->setEnabled(isDesktopItem) ;
 }
