@@ -26,10 +26,10 @@ class CfgTerminalEmulator: public QWidget, public Ui::TerminalEmulatorConfig_UI,
     Q_OBJECT
 public:
 	CfgTerminalEmulator(QWidget *parent);
-	virtual ~CfgTerminalEmulator();
-	void load(KConfig *cfg) Q_DECL_OVERRIDE;
-	void save(KConfig *cfg) Q_DECL_OVERRIDE;
-	void defaults() Q_DECL_OVERRIDE;
+	~CfgTerminalEmulator() override;
+	void load(KConfig *cfg) override;
+	void save(KConfig *cfg) override;
+	void defaults() override;
 
 protected Q_SLOTS:
 	void selectTerminalApp();
